betty.jinja2 package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.jinja2 package

## Submodules

- betty.jinja2.filter module
  - `filter_base64()`
  - `filter_file()`
  - `filter_flatten()`
  - `filter_format_datey()`
  - `filter_format_degrees()`
  - `filter_hashid()`
  - `filter_image()`
  - `filter_json()`
  - `filter_localize()`
  - `filter_map()`
  - `filter_negotiate_dateds()`
  - `filter_negotiate_localizeds()`
  - `filter_paragraphs()`
  - `filter_public_css()`
  - `filter_public_js()`
  - `filter_select_dateds()`
  - `filter_select_localizeds()`
  - `filter_sort_localizeds()`
  - `filter_static_url()`
  - `filter_unique()`
  - `filter_url()`
  - `filter_walk()`
- betty.jinja2.test module
  - `test_date_range()`
  - `test_end_of_life_event()`
  - `test_entity()`
  - `test_has_files()`
  - `test_has_generated_entity_id()`
  - `test_has_links()`
  - `test_linked_data_dumpable()`
  - `test_start_of_life_event()`
  - `test_subject_role()`
  - `test_user_facing_entity()`
  - `test_witness_role()`

## Module contents

Provide rendering utilities using Jinja2.

class betty.jinja2.EntityContexts

  Bases: `object`

  Track the current entity contexts.

  To allow templates to respond to their environment, this class allows our templates to set and get one entity per entity type for the current context.

  Use cases include rendering an entity label as plain text if the template is in that entity’s context, but as a hyperlink if the template is not in the entity’s context.

  Parameters:

    entities (`betty.model.Entity`)

  __init__(*entities: betty.model.Entity) → None
    Parameters:

      entities (`betty.model.Entity`)

class betty.jinja2.Environment

  Bases: `Environment`

  Betty’s Jinja2 environment.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

  property context_class: type[Context]

    The template context holds the variables of a template. It stores the values passed to the template and also the names the template exports. Creating instances is neither supported nor useful as it’s created automatically at various stages of the template evaluation and should not be created by hand.

    The context is immutable. Modifications on `parent` must not happen and modifications on `vars` are allowed from generated template code only. Template filters and global functions marked as `pass_context()` get the active context passed as first argument and are allowed to access the context read-only.

    The template context supports read only dict operations (get, keys, values, items, iterkeys, itervalues, iteritems, __getitem__, __contains__). Additionally there is a `resolve()` method that doesn’t fail with a KeyError but returns an `Undefined` object for missing variables.

  filters: dict[str, Callable[..., Any]]
  globals: dict[str, Any]
  tests: dict[str, Callable[..., bool]]

class betty.jinja2.Jinja2Provider

  Bases: `object`

  Integrate an `betty.app.extension.Extension` with the Jinja2 API.

  property filters: dict[str, Callable[[...], Any]]

    Jinja2 filters provided by this extension.

    Keys are filter names, and values are the filters themselves.

  property globals: dict[str, Any]

    Jinja2 globals provided by this extension.

    Keys are the globals’ names, and values are the globals’ values.

  new_context_vars() → dict[str, Any]

    Create new variables for a new `jinja2.runtime.Context`.

    Keys are the variable names, and values are variable values.

    Return type:

      `dict`[`str`, `typing.Any`]

  property tests: dict[str, Callable[[...], bool]]

    Jinja2 tests provided by this extension.

    Keys are test names, and values are the tests themselves.

class betty.jinja2.Jinja2Renderer

  Bases: `Renderer`

  Render content as Jinja2 templates.

  Parameters:

    - environment (`betty.jinja2.Environment`)

    - configuration (`betty.project.ProjectConfiguration`)

  __init__(environment: betty.jinja2.Environment, configuration: betty.project.ProjectConfiguration)
    Parameters:

      - environment (`betty.jinja2.Environment`)

      - configuration (`betty.project.ProjectConfiguration`)

  property file_extensions: set[str]

    The extensions of the files this renderer can render.

  async render_file(file_path: pathlib.Path, *, job_context: betty.job.Context | None = None, localizer: betty.locale.Localizer | None = None) → pathlib.Path

    Render a single file.

    Return type:

      `pathlib.Path`

    Returns:

      The file’s new path, which may have been changed, e.g. a renderer-specific extension may have been stripped from the end.

    Parameters:

      - file_path (`pathlib.Path`)

      - job_context (`betty.job.Context` | `None`)

      - localizer (`betty.locale.Localizer` | `None`)

betty.jinja2.context_app(context: jinja2.runtime.Context) → betty.app.App

  Get the current app from the Jinja2 context.

  Parameters:

    context (`jinja2.runtime.Context`)

  Return type:

    `betty.app.App`

betty.jinja2.context_job_context(context: jinja2.runtime.Context) → betty.job.Context | None

  Get the current job context from the Jinja2 context.

  Parameters:

    context (`jinja2.runtime.Context`)

  Return type:

    `betty.job.Context` | `None`

betty.jinja2.context_localizer(context: jinja2.runtime.Context) → betty.locale.Localizer

  Get the current localizer from the Jinja2 context.

  Parameters:

    context (`jinja2.runtime.Context`)

  Return type:

    `betty.locale.Localizer`